gepref\_text package
====================

Submodules
----------

gepref\_text.base module
------------------------

.. automodule:: gepref_text.base
   :members:
   :undoc-members:
   :show-inheritance:

gepref\_text.filtering module
-----------------------------

.. automodule:: gepref_text.filtering
   :members:
   :undoc-members:
   :show-inheritance:

gepref\_text.normalization module
---------------------------------

.. automodule:: gepref_text.normalization
   :members:
   :undoc-members:
   :show-inheritance:

gepref\_text.regex\_sub module
------------------------------

.. automodule:: gepref_text.regex_sub
   :members:
   :undoc-members:
   :show-inheritance:

gepref\_text.tokenization module
--------------------------------

.. automodule:: gepref_text.tokenization
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: gepref_text
   :members:
   :undoc-members:
   :show-inheritance:
